pub fn build_add_order_params(
cmd: &SubmitOrder,
order: &OrderAny,
token: String,
leverage: Option<u16>,
) -> Result<KrakenWsAddOrderParams>Expand description
Builds WebSocket add_order parameters from a Nautilus submit command and the cached order.
Errors
Returns an error if:
- The order side cannot be mapped to a Kraken side.
- The order type is not supported on the WS path.
- The time in force is not supported for the given order type.
- GTD time in force is missing
expire_time.